Flask-Manifest
==============

This plugin aims to help integrate any asset pipeline that generates a static
file manifest with Flask.

While it's a work in progress and the API is not finalised, I'm currently using
it for a project. As this project evolves, the extension's scope and eventual
features will become more concrete.
